@@ -32,7 +32,6 @@ class TimeUnit(Enum):
     HOURS = 7
 
 
-
 class ColumnType(Enum):
     String = "string"
     Double = "double"
@@ -65,9 +64,15 @@ class DecimalStringFormat:
         self.minDecimals = min
         self.maxDecimals = max
 
+
+class ImageFormat:
+    type = "image"
+
+
 class HTMLFormat:
     type = "html"
 
+
 class HighlightStyle(Enum):
     FULL_ROW = 1
     SINGLE_COLUMN = 2
@@ -91,12 +96,19 @@ class TableDisplayCellRenderer:
 
 
 class TableDisplayStringFormat:
+
     @staticmethod
     def getDecimalFormat(min, max):
         return DecimalStringFormat(min, max)
+
+    @staticmethod
     def getHTMLFormat():
         return HTMLFormat()
 
+    @staticmethod
+    def getImageFormat():
+        return ImageFormat()
+
 class TableDisplayCellHighlighter:
     FULL_ROW = HighlightStyle.FULL_ROW
     SINGLE_COLUMN = HighlightStyle.SINGLE_COLUMN
